package com.nwalsh.saxon6;

import org.xml.sax.*;
import com.icl.saxon.output.*;
import com.icl.saxon.om.*;
import com.icl.saxon.tinytree.TinyBuilder;
import com.icl.saxon.expr.FragmentValue;
import com.icl.saxon.Builder;

/**
 * <p>Saxon extension to scan the column widthsin a result tree fragment.</p>
 *
 * <p>$Id: ColumnScanEmitter.java,v 1.1 2000/12/12 12:15:56 ndw Exp $</p>
 *
 * <p>Copyright (C) 2000 Norman Walsh.</p>
 *
 * <p>This class provides a
 * <a href="http://users.iclway.co.uk/mhkay/saxon/">Saxon 6.*</a>
 * implementation to scan the column widths in a result tree
 * fragment.</p>
 *
 * <p>The general design is this: the stylesheets construct a result tree
 * fragment for some colgroup environment. That result tree fragment
 * is "replayed" through the ColumnScanEmitter; the ColumnScanEmitter watches
 * the cols go by and extracts the column widths that it sees. These
 * widths are then made available.</p>
 *
 * <p><b>Change Log:</b></p>
 * <dl>
 * <dt>1.0</dt>
 * <dd><p>Initial release.</p></dd>
 * </dl>
 *
 * @author Norman Walsh
 * <a href="mailto:ndw@nwalsh.com">ndw@nwalsh.com</a>
 *
 * @version $Id: ColumnScanEmitter.java,v 1.1 2000/12/12 12:15:56 ndw Exp $
 *
 */
public class ColumnScanEmitter implements com.icl.saxon.output.Emitter {
  /** The number of columns seen. */
  protected int numColumns = 0;
  protected String width[] = new String[5];
  protected NamePool namePool = null;

  /** Construct a new ColumnScanEmitter. */
  public ColumnScanEmitter(NamePool namePool) {
    numColumns = 0;
    this.namePool = namePool;
  }

  /** Return the number of columns. */
  public int columnCount() {
    return numColumns;
  }

  /** Return the number of columns. */
  public String[] columnWidths() {
    return width;
  }

  /** Discarded. */
  public void characters(char[] chars, int start, int len)
    throws org.xml.sax.SAXException {
    // nop
  }

  /** Discarded. */
  public void comment(char[] chars, int start, int length)
    throws org.xml.sax.SAXException {
    // nop
  }

  /** Discarded. */
  public void endDocument()
    throws org.xml.sax.SAXException {
    // nop
  }

  /** Discarded. */
  public void endElement(int nameCode)
    throws org.xml.sax.SAXException {
    // nop
  }

  /** Discarded. */
  public void processingInstruction(java.lang.String name,
				    java.lang.String data)
    throws org.xml.sax.SAXException {
    // nop
  }

  /** Discarded. */
  public void setCharacterSet(CharacterSet charset)
    throws org.xml.sax.SAXException {
    // nop
  }

  /** Discarded. */
  public void setDocumentLocator(org.xml.sax.Locator locator) {
    // nop
  }

  /** Discarded. */
  public void setEscaping(boolean escaping)
    throws org.xml.sax.SAXException {
    // nop
  }

  /** Discarded. */
  public void setNamePool(NamePool namePool) {
    // nop
  }

  /** Discarded. */
  public void setOutputDetails(OutputDetails details)
    throws org.xml.sax.SAXException {
    // nop
  }

  /** Discarded. */
  public void setUnparsedEntity(java.lang.String name, java.lang.String uri)
    throws org.xml.sax.SAXException {
    // nop
  }

  /** Discarded. */
  public void setWriter(java.io.Writer writer)
    throws org.xml.sax.SAXException {
    // nop
  }

  /** Discarded. */
  public void startDocument()
    throws org.xml.sax.SAXException {
    // nop
  }

  /** Examine for column info. */
  public void startElement(int nameCode,
		    org.xml.sax.Attributes attributes,
		    int[] namespaces, int nscount)
    throws org.xml.sax.SAXException {

    int colFingerprint = namePool.getFingerprint("", "col");
    if (nameCode == colFingerprint) {
      if (numColumns > width.length) {
	String newWidth[] = new String[width.length+10];
	for (int count = 0; count < width.length; count++) {
	  newWidth[count] = width[count];
	}
	width = newWidth;
      }

      if (attributes.getValue("width") == null) {
	width[numColumns++] = "1*";
      } else {
	width[numColumns++] = attributes.getValue("width");
      }
    }
  }
}


